cmmanager/cmmgr/Plugins/cmpluginwlan/src/cmpluginwlan.cpp
changeset 2 086aae6fc07e
parent 0 5a93021fdf25
child 12 ea6e024ea6f9
--- a/cmmanager/cmmgr/Plugins/cmpluginwlan/src/cmpluginwlan.cpp	Thu Jan 07 12:56:54 2010 +0200
+++ b/cmmanager/cmmgr/Plugins/cmpluginwlan/src/cmpluginwlan.cpp	Mon Jan 18 20:33:49 2010 +0200
@@ -68,7 +68,11 @@
 const TInt KWlanLastSocketClosedTimeout = -1;
 const TUint32 KEndOfArray = KMaxTUint;
 
-/// Modem bearer names for WLAN connection methods
+// Daemon manager name for Easy WLAN IAP
+_LIT( KHotspotDaemonManagerName, "NetCfgExtnHotSpot" );
+_LIT( KEasyWlanName, "Easy WLAN" );
+
+// Modem bearer names for WLAN connection methods
 _LIT( KModemBearerWLAN, "WLANBearer" );
 
 _LIT( KWlanFileIcons, "z:cmpluginwlan.mbm" );
@@ -2741,6 +2745,24 @@
     	    }
         delete daemonName;
         }
+       
+    // check if Easy WLAN IAP since it has different config daemon
+    // manager name
+    HBufC* iapName = GetStringAttributeL( ECmName );
+    if ( iapName )
+        {
+        CleanupStack::PushL( iapName );
+        if ( iapName->Compare( KEasyWlanName ) == 0 )
+            {
+            SetStringAttributeL( ECmConfigDaemonManagerName, 
+                                  KHotspotDaemonManagerName );
+            SetStringAttributeL( ECmConfigDaemonName, 
+                                   KConfigDaemonName );
+            CleanupStack::PopAndDestroy( iapName );
+            return;
+            }
+        CleanupStack::PopAndDestroy( iapName );
+        }
         
     // use DHCP if we can
     TBool ipfromSrv = GetBoolAttributeL( ECmIPAddFromServer );